class Unit:
    def __init__(self):
        self.unit_name = "Unit"
        self.description = None
        self.documentation = None
        self.requires = None
        self.wants = None
        self.binds_to = None
        self.before = None
        self.after = None
        self.conflicts = None
        self.condition = None
        self.assert_ = None