class Mount:
    def __init__(self):
        self.unit_name = "Mount"
        self.what = None
        self.where = None
        self.type = None
        self.options = None
        self.sloppy_options = None
        self.directory_mode = None
        self.timeout_sec = None