class Install:
    def __init__(self):
        self.unit_name = "Install"
        self.wanted_by = None
        self.required_by = None
        self.alias = None
        self.also = None
        self.defaul_instance = None