class Path:
    def __init__(self):
        self.unit_name = "Path"
        self.path_exists = None
        self.path_exists_glob = None
        self.path_changed = None
        self.path_modified = None
        self.directory_not_empty = None
        self.unit = None
        self.make_directory = None
        self.directory_mode = None
        